# -*- coding: utf-8 -*-

"""
--------------------------------------------
project: zibuyu_wechat
author: 子不语
date: 2024/11/15
contact: 【公众号】思维兵工厂
description: 
--------------------------------------------
"""


class OfficialApisManager(object):
    """微信公众号官方接口地址"""

    host_list = [
        "https://api.weixin.qq.com",  # 通用域名，访问官方指定就近的接入点
        "https://api2.weixin.qq.com",  # 通用异地容灾域名，当上述域名不可访问时可改访问此域名
        "https://sh.api.weixin.qq.com",  # 上海域名，访问上海的接入点
        "https://sz.api.weixin.qq.com",  # 深圳域名，访问深圳的接入点
        "https://hk.api.weixin.qq.com"  # 香港域名，访问香港的接入点
    ]

    # 未分类
    token_uri = "/cgi-bin/token"  # 获取token
    get_keyword_uri = "/cgi-bin/get_current_autoreply_info"  # 获取公众号的自动回复规则
    voice_to_text_uri = "/cgi-bin/media/voice/addvoicetorecofortext"  # 智能接口
    msg_record_url = "https://api.weixin.qq.com/customservice/msgrecord/getmsglist"  # 获取客服聊天记录

    # 临时素材相关接口
    soft_src_upload_uri = "/cgi-bin/media/upload"  # 上传临时素材
    soft_src_download_uri = "/cgi-bin/media/get"  # 下载临时素材

    # 永久素材相关接口
    hard_img_upload_uri = "/cgi-bin/media/uploadimg"  # 上传图文消息内的图片获取URL
    hard_src_upload_uri = "/cgi-bin/material/add_material"  # 上传其他类型永久素材：图片、语音、视频和缩略图
    hard_src_download_uri = "/cgi-bin/material/get_material"  # 下载永久素材
    hard_src_delete_uri = "/cgi-bin/material/del_material"  # 删除永久素材
    hard_src_count_uri = "/cgi-bin/material/get_materialcount"  # 获取永久素材的各类总数列表
    hard_src_list_uri = "/cgi-bin/material/batchget_material"  # 获取永久素材的列表

    # 菜单相关接口
    get_menu_uri = "/cgi-bin/get_current_selfmenu_info"  # 查询当前菜单
    create_menu_uri = "/cgi-bin/menu/create"  # 创建菜单
    delete_menu_uri = "/cgi-bin/menu/delete"  # 删除菜单

    # 草稿相关接口
    create_draft_uri = "/cgi-bin/draft/add"  # 新建素材
    get_draft_uri = "/cgi-bin/draft/get"  # 获取素材
    delete_draft_uri = "/cgi-bin/draft/delete"  # 删除素材
    update_draft_uri = "/cgi-bin/draft/update"  # 修改素材
    get_draft_count_uri = "/cgi-bin/draft/count"  # 获取素材总数
    get_draft_list_uri = "/cgi-bin/draft/batchget"  # 获取素材列表

    # 清除api接口调用的额度限制
    clear_quota_uri = "/cgi-bin/clear_quota"  # 清空api的调用quota，每月可以清除10次
    check_quota_uri = "/cgi-bin/openapi/quota/get"  # 查询api接口的每日调用额度和调用次数

    # 发布相关
    publish_news_uri = "/cgi-bin/freepublish/submit"  # 发布草稿
    publish_status_uri = "/cgi-bin/freepublish/get"  # 查询发布状态
    article_list_uri = "/cgi-bin/freepublish/batchget"  # 获取已发布图文列表
    get_article_uri = "/cgi-bin/freepublish/getarticle"  # 获取已发布的图文
    del_article_uri = "/cgi-bin/freepublish/delete"  # 删除已发布的图文

    def __init__(self, domain: str = ''):
        """

        :param domain: 域名，默认为空，使用通用域名
        """
        if not domain or domain not in self.host_list:
            self.base_pre_url = self.host_list[0]

    @property
    def token_url(self):
        """获取token接口地址"""
        return self.base_pre_url + self.token_uri

    @property
    def soft_src_upload_url(self):
        return self.base_pre_url + self.soft_src_upload_uri

    @property
    def soft_src_download_url(self):
        return self.base_pre_url + self.soft_src_download_uri

    @property
    def hard_img_upload_url(self):
        """上传图文消息内的图片获取URL接口地址"""
        return self.base_pre_url + self.hard_img_upload_uri

    @property
    def hard_src_upload_url(self):
        """上传其他类型永久素材接口地址"""
        return self.base_pre_url + self.hard_src_upload_uri

    @property
    def hard_src_download_url(self):
        """下载永久素材接口地址"""
        return self.base_pre_url + self.hard_src_download_uri

    @property
    def hard_src_delete_url(self):
        """删除永久素材接口地址"""
        return self.base_pre_url + self.hard_src_delete_uri

    @property
    def hard_src_count_url(self):
        """获取永久素材的各类总数列表接口地址"""
        return self.base_pre_url + self.hard_src_count_uri

    @property
    def hard_src_list_url(self):
        """获取永久素材的列表接口地址"""
        return self.base_pre_url + self.hard_src_list_uri

    @property
    def get_keyword_url(self):
        """获取公众号的自动回复规则接口地址"""
        return self.base_pre_url + self.get_keyword_uri

    @property
    def get_menu_url(self):
        """查询当前菜单接口地址"""
        return self.base_pre_url + self.get_menu_uri

    @property
    def create_menu_url(self):
        """创建菜单接口地址"""
        return self.base_pre_url + self.create_menu_uri

    @property
    def delete_menu_url(self):
        """删除菜单接口地址"""
        return self.base_pre_url + self.delete_menu_uri

    @property
    def create_draft_url(self):
        """新建素材接口地址"""
        return self.base_pre_url + self.create_draft_uri

    @property
    def get_draft_url(self):
        """获取素材接口地址"""
        return self.base_pre_url + self.get_draft_uri

    @property
    def delete_draft_url(self):
        """删除素材接口地址"""
        return self.base_pre_url + self.delete_draft_uri

    @property
    def update_draft_url(self):
        """修改素材接口地址"""
        return self.base_pre_url + self.update_draft_uri

    @property
    def get_draft_count_url(self):
        """获取素材总数接口地址"""
        return self.base_pre_url + self.get_draft_count_uri

    @property
    def get_draft_list_url(self):
        """获取素材列表接口地址"""
        return self.base_pre_url + self.get_draft_list_uri

    @property
    def clear_quota_url(self):
        """清空api的调用quota接口地址"""
        return self.base_pre_url + self.clear_quota_uri

    @property
    def check_quota_url(self):
        """查询api接口的每日调用额度和调用次数接口地址"""
        return self.base_pre_url + self.check_quota_uri

    @property
    def publish_news_url(self):
        """发布草稿接口地址"""
        return self.base_pre_url + self.publish_news_uri

    @property
    def publish_status_url(self):
        """查询发布状态接口地址"""
        return self.base_pre_url + self.publish_status_uri

    @property
    def article_list_url(self):
        """获取已发布图文列表接口地址"""
        return self.base_pre_url + self.article_list_uri

    @property
    def del_article_url(self):
        return self.base_pre_url + self.del_article_uri

    @property
    def get_article_url(self):
        """获取已发布的图文接口地址"""
        return self.base_pre_url + self.get_article_uri

    @property
    def voice_to_text_url(self):
        """语音转文字接口地址"""
        return self.base_pre_url + self.voice_to_text_uri


class OfficialWebApisManager(object):
    """微信公众号网页逆向相关接口"""

    # 接口基础域名
    base_pre_url = 'https://mp.weixin.qq.com'

    # 设置关键词回复接口
    set_reply_rule_url = f'{base_pre_url}/advanced/setreplyrule'
